[![logo](https://signalboa.com/wp-content/uploads/2021/11/Signal_Boa_Logo_Inverse-1.png)](http://signalboa.com "SignalBoa - AI-powered Buy & Sell of Crypto")

Python connector to the [SignalBoa API](https://signalboa.com/signals "Signals")
===================================================================================


